@@ -18,6 +18,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 @author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
  */
 
+#include "options.h"
+
 #include "mystring.h"
 
 /**
@@ -47,6 +49,21 @@ void split_get_params(connection_t* connection_prop) {
     }
     connection_prop->page_len=i;
 }
+/*void split_get_params(connection_t* connection_prop) {
+    char *separator=strstr(connection_prop->page,"?");
+
+    if (separator==NULL) {
+        connection_prop->get_params=NULL;
+        connection_prop->page_len=strlen(connection_prop->page);
+
+    } else {
+
+        separator[0]=0;
+        connection_prop->get_params=separator+1;
+        connection_prop->page_len=separator-connection_prop->page;
+
+    }
+}*/
 
 
 /**
@@ -94,71 +111,30 @@ void strReplace(char *string, char *substr, char with) {
 This function deletes n chars from the string, starting from the position pos.
 In case deleting of more chars than the string's len itself, the string will be returned unchanged.
 
-This function is in-place, doesn't create copies but changes the original string.
+This function doesn't create copies but changes the original string.
 */
 void delChar(char *string, int pos, int n) {
-    /*
-    This isn't using strcpy because here the strings overlap.
-    memmove isn't good too because
-    */
-    if (strlen(string+pos) < n) { //String is long enough
-        return;
-    }
+    size_t l=strlen(string+pos);
 
-    char *c1, *c2;
-    for (c1 = string + pos, c2 = c1 + n; *c2 != 0; c1++, c2++) {
-        *c1 = *c2;
-    }
-    *c1 = 0;
-}
+    if (l<n) return;
+    l-=n;
+    memmove(string+pos,string+pos+n,l);
+    string[l]=0;
 
-
-
-/**
-This function changes param's separator from & to \0, to create several strings.
-Returns number of strings
-*/
-int splitParams(char *string) {
-    int params = 0;
-    int i;
-    int to = strlen(string);
-
-    for (i = 0; i < to; i++) {
-        if (string[i] == '&') {
-            string[i] = '\0';
-            params++;
-        }
-    }
-    return params + 1;
+    return;
 }
 
 /**
 Returns true if str ends with end
 
 str String to compare
-end second string. If str ends with end, true is returned
+end second string
+size of str
+size of end
+
+If str ends with end, true is returned
 false otherwise
 */
 bool endsWith(char *str, char *end,ssize_t len_str,ssize_t len_end) {
-    int i;
-
-    for (i = 1; i <= len_end; i++) {
-        if (end[len_end - i] != str[len_str - i])
-            return false;
-    }
-
-    return true;
-}
-
-/**
-Removes cr lf chars from the beginning of the string
-
-This function is in-place, doesn't create copies but changes the original string.
-*/
-int removeCrLf(char *buf) { //Removing initial \n or \r
-    int count = 0;
-    while (buf[count] == 10 || buf[count] == 13)
-        count++;
-    delChar(buf, 0, count);
-    return count;
+    return strcmp(str+len_str-len_end,end)==0;
 }
