@@ -20,6 +20,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 @author Salvo Rinaldi <salvin@anche.no>
 */
 
+#include "options.h"
+
+#include <stdlib.h>
+#include <pthread.h>
+#include <netinet/in.h>
+
 #include "queue.h"
 
 /**
